@@ -22,6 +22,20 @@ class BaseInquirer(ABC):
             List of valid format options
         """
 
+    @abstractmethod
+    def set_sacct_args(self, jobs: List[str]) -> List[str]:
+        """Set arguments of sacct query.
+
+        Args:
+            jobs: list of job names
+
+        Returns:
+            String of sacct arguments
+
+        Raises:
+            RuntimeError: if sacct doesn't return properly
+        """
+
     @abstractmethod
     def get_db_output(
         self,
@@ -40,6 +54,7 @@ class BaseInquirer(ABC):
             List of rows, where each row is a dictionary
             with the columns as keys and entries as values
             Output order is not garunteed to match the jobs list
+
         """
 
     @abstractmethod
@@ -70,6 +85,26 @@ class BaseInquirer(ABC):
             state: comma separated list of state names or codes
         """
 
+    @abstractmethod
+    def parse_date(self, d: str) -> str:
+        """Parse and convert custom string date format.
+
+        Args:
+            d: the string of date.
+
+        Returns:
+            converted string of date
+        """
+
+    @abstractmethod
+    def set_until(self, until: str) -> None:
+        """Set the filter for time of jobs to consider.
+
+        Args:
+            until: the string for filtering.  If specified as time=amount
+                will subtract that amount from the current time
+        """
+
     @abstractmethod
     def set_since(self, since: str) -> None:
         """Set the filter for time of jobs to consider.
@@ -106,6 +141,7 @@ class SacctInquirer(BaseInquirer):
         self.state: Optional[Set] = None
         self.not_state: Optional[Set] = None
         self.since: Optional[str] = None
+        self.until: Optional[str] = None
         self.query_all_users: bool = False
 
     def get_valid_formats(self) -> List[str]:
@@ -131,6 +167,32 @@ class SacctInquirer(BaseInquirer):
         result = cmd_result.stdout.split()
         return result
 
+    def set_sacct_args(self, jobs: List[str]) -> List[str]:
+        """Set arguments of sacct query.
+
+        Args:
+            jobs: list of job names
+
+        Returns:
+            String of sacct arguments
+
+        """
+        args = []
+        if self.user:
+            if not self.since:
+                start_date = datetime.date.today() - datetime.timedelta(days=7)
+                self.since = start_date.strftime("%m%d%y")  # MMDDYY
+            args += [f"--user={self.user}", f"--starttime={self.since}"]
+        elif self.query_all_users:
+            args += ["--allusers", f"--starttime={self.since}"]
+        else:
+            args += ["--jobs=" + ",".join(jobs)]
+            if self.since:
+                args += [f"--starttime={self.since}"]
+        if self.until:
+            args += [f"--endtime={self.until}"]
+        return args
+
     def get_db_output(
         self,
         columns: List[str],
@@ -153,19 +215,7 @@ class SacctInquirer(BaseInquirer):
             RuntimeError: if sacct doesn't return properly
         """
         args = self.default_args + ["--format=" + ",".join(columns)]
-
-        if self.user:
-            if not self.since:
-                start_date = datetime.date.today() - datetime.timedelta(days=7)
-                self.since = start_date.strftime("%m%d%y")  # MMDDYY
-            args += [f"--user={self.user}", f"--starttime={self.since}"]
-        elif self.query_all_users:
-            args += ["--allusers", f"--starttime={self.since}"]
-        else:
-            args += ["--jobs=" + ",".join(jobs)]
-            if self.since:
-                args += [f"--starttime={self.since}"]
-
+        args += self.set_sacct_args(jobs)
         try:
             cmd_result = subprocess.run(
                 args=args,
@@ -228,6 +278,7 @@ class SacctInquirer(BaseInquirer):
 
         Args:
             state: comma separated list of state names or codes
+
         """
         if not state:
             return
@@ -238,6 +289,66 @@ class SacctInquirer(BaseInquirer):
             click.secho("No valid states provided to exclude", fg="yellow", err=True)
             self.not_state = None
 
+    def parse_date(self, d: str) -> str:
+        """Parse and convert custom string date format.
+
+        Args:
+            d: the string of date.
+
+        Returns:
+            converted string of date
+        """
+        abbrev_to_key = {
+            "w": "weeks",
+            "W": "weeks",
+            "d": "days",
+            "D": "days",
+            "h": "hours",
+            "H": "hours",
+            "m": "minutes",
+            "M": "minutes",
+        }
+        valid_args = ["weeks", "days", "hours", "minutes"]
+        date_args = {}
+
+        args = d.split(",")
+        for arg in args:
+            toks = arg.split("=")
+
+            # lines don't have an equal
+            if len(toks) < 2:
+                continue
+
+            # convert key to name
+            if toks[0] in abbrev_to_key:
+                toks[0] = abbrev_to_key[toks[0]]
+
+            toks[0] = toks[0].lower()
+
+            if toks[0] in valid_args:
+                try:
+                    date_args[toks[0]] = int(toks[1])
+                except ValueError:
+                    continue
+
+        date = datetime.datetime.today()
+        date -= datetime.timedelta(**date_args)
+        return date.strftime("%Y-%m-%dT%H:%M")  # MMDDYY
+
+    def set_until(self, until: str) -> None:
+        """Set the filter for time of jobs to consider.
+
+        Args:
+            until: the string for filtering. If specified as time=amount
+                will subtract that amount from the current time
+        """
+        if not until:
+            return
+        if "=" in until:  # handle custom format
+            self.until = self.parse_date(until)
+        else:
+            self.until = until
+
     def set_since(self, since: str) -> None:
         """Set the filter for time of jobs to consider.
 
@@ -248,43 +359,7 @@ class SacctInquirer(BaseInquirer):
         if not since:
             return
         if "=" in since:  # handle custom format
-            abbrev_to_key = {
-                "w": "weeks",
-                "W": "weeks",
-                "d": "days",
-                "D": "days",
-                "h": "hours",
-                "H": "hours",
-                "m": "minutes",
-                "M": "minutes",
-            }
-            valid_args = ["weeks", "days", "hours", "minutes"]
-            date_args = {}
-
-            args = since.split(",")
-            for arg in args:
-                toks = arg.split("=")
-
-                # lines don't have an equal
-                if len(toks) < 2:
-                    continue
-
-                # convert key to name
-                if toks[0] in abbrev_to_key:
-                    toks[0] = abbrev_to_key[toks[0]]
-
-                toks[0] = toks[0].lower()
-
-                if toks[0] in valid_args:
-                    try:
-                        date_args[toks[0]] = int(toks[1])
-                    except ValueError:
-                        continue
-
-            start_date = datetime.datetime.today()
-            start_date -= datetime.timedelta(**date_args)
-            self.since = start_date.strftime("%Y-%m-%dT%H:%M")  # MMDDYY
-
+            self.since = self.parse_date(since)
         else:
             self.since = since
 
